@@ -1,8 +1,9 @@
-use flow_impl::{Implementation, RUN_AGAIN, RunAgain};
-use flow_impl_derive::FlowImpl;
 use serde_json::json;
 use serde_json::Value;
 
+use flow_impl_derive::FlowImpl;
+use flowcore::{Implementation, RunAgain, RUN_AGAIN};
+
 #[derive(FlowImpl)]
 /// Takes a value on it's input and sends the same value on it's output and adds one to the count
 /// received on 'count' input and outputs new count on 'count' output
@@ -28,16 +29,17 @@ impl Implementation for Count {
 
 #[cfg(test)]
 mod test {
-    use flow_impl::Implementation;
     use serde_json::json;
 
+    use flowcore::Implementation;
+
     use super::Count;
 
     #[test]
     fn count_returns_value() {
         let data = json!(42);
         let count = json!(0);
-        let inputs = vec!(data, count);
+        let inputs = vec![data, count];
 
         let counter = Count {};
         let (result, _) = counter.run(&inputs);
@@ -46,4 +48,4 @@ mod test {
         assert_eq!(output.pointer("/data").unwrap(), &json!(42));
         assert_eq!(output.pointer("/count").unwrap(), &json!(1));
     }
-}
\ No newline at end of file
+}
