@@ -1,8 +1,9 @@
-use flow_impl::{Implementation, RUN_AGAIN, RunAgain};
-use flow_impl_derive::FlowImpl;
 use serde_json::json;
 use serde_json::Value;
 
+use flow_impl_derive::FlowImpl;
+use flowcore::{Implementation, RUN_AGAIN, RunAgain};
+
 #[derive(FlowImpl)]
 /// Multiply one input by another
 #[derive(Debug)]
@@ -22,18 +23,19 @@ impl Implementation for Multiply {
 
 #[cfg(test)]
 mod test {
-    use flow_impl::Implementation;
     use serde_json::{json, Value};
 
+    use flowcore::Implementation;
+
     use super::Multiply;
 
     fn do_multiply(test_data: (u32, u32, u32)) {
-        let multiplier: &dyn Implementation = &Multiply{} as &dyn Implementation;
+        let multiplier: &dyn Implementation = &Multiply {} as &dyn Implementation;
 
         // Create input vector
         let i1 = json!(test_data.0);
         let i2 = json!(test_data.1);
-        let inputs: Vec<Value> = vec!(i1, i2);
+        let inputs: Vec<Value> = vec![i1, i2];
 
         let (output, run_again) = multiplier.run(&inputs);
         assert!(run_again);
@@ -44,10 +46,10 @@ mod test {
 
     #[test]
     fn test_divide() {
-        let test_set = vec!((3, 3, 9), (33, 3, 99));
+        let test_set = vec![(3, 3, 9), (33, 3, 99)];
 
         for test in test_set {
             do_multiply(test);
         }
     }
-}
\ No newline at end of file
+}
